#!/bin/bash
#
# MSP Service

PATH=$HOME/.docker/cli-plugins:/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin

config_msp() {
  echo -ne "\n* Configuring /federated/apps/msp container.."
  spin &
  SPINPID=$!

  if [ ! -d "/federated/apps/msp" ]; then
    mkdir -p /federated/apps/msp/data
  fi

ADMINPASS=`cat /federated/apps/panel/.env | grep SMTP_PASSWORD | awk -F= '{ print $2 }'`
TRAEFIK_HTTPAUTH_STRING_MSP=$(echo `htpasswd -nb admin@$DOMAIN $ADMINPASS` | sed -e s/\\$/\\$\\$/g)

cat > /federated/apps/msp/docker-compose.yml <<EOF
version: '3.7'

services:
  msp:
    image: thebells1111/federated-msp:\${IMAGE_VERSION}
    container_name: msp
    hostname: msp.$DOMAIN
    domainname: $DOMAIN
    restart: always
    networks:
      federated:
        ipv4_address: 172.99.0.38
    volumes:
      - ./data/var/docker/msp/credentials:/usr/src/app/msp/credentials
      - ./data/var/docker/msp/mspDB:/usr/src/app/msp/mspDB
      - ./data/var/docker/msp/albums:/usr/src/app/msp/public
    env_file:
      - ./.env
    labels:
      - "traefik.enable=true"
      - "traefik.http.routers.msp.rule=Host(\`msp.$DOMAIN\`)"
      - "traefik.http.routers.msp.service=msp"
      - "traefik.http.routers.msp.entrypoints=websecure"
      - "traefik.http.routers.msp.tls.certresolver=letsencrypt"
      - "traefik.http.services.msp.loadbalancer.server.port=3000"
      - "traefik.http.routers.msp.middlewares=msp-auth"
      - "traefik.http.middlewares.msp-auth.basicauth.users=$TRAEFIK_HTTPAUTH_STRING_MSP"
      - "traefik.http.routers.mspnew.rule=Host(\`msp.$DOMAIN\`) && PathPrefix(\`/albums\`)"
      - "traefik.http.routers.mspnew.entrypoints=websecure"
      - "traefik.http.routers.mspnew.tls.certresolver=letsencrypt"
      - "traefik.http.routers.mspnew.service=mspnew"
      - "traefik.http.services.mspnew.loadbalancer.server.port=3000"

networks:
  federated:
    external: true
EOF

cat > /federated/apps/msp/.env <<EOF
IMAGE_VERSION="latest"
EOF
chmod 600 /federated/apps/msp/.env

kill -9 $SPINPID &> /dev/null
echo -ne "done."
}
start_msp() {
  # Start service with command to make sure it's up before proceeding
  start_service "msp" "nc -z 172.99.0.38 3000 &> /dev/null" "7"

  docker exec pdns pdnsutil add-record $DOMAIN msp A 86400 $EXTERNALIP
  [ $? -ne 0 ] && fail "Couldn't add dns record for msp"

  kill -9 $SPINPID &> /dev/null
  echo -ne "done."
}
